/* This file is automatically generated by configure.  Do not modify by hand. */
  if (should_init("snmpMPDStats")) shutdown_snmpMPDStats();
  if (should_init("usmStats")) shutdown_usmStats();
  if (should_init("sysORTable")) shutdown_sysORTable();
  if (should_init("pass_persist")) shutdown_pass_persist();
  if (should_init("extend")) shutdown_extend();
  if (should_init("dlmod")) shutdown_dlmod();
  if (should_init("proxy")) shutdown_proxy();
  if (should_init("snmpNotifyTable")) shutdown_snmpNotifyTable();
  if (should_init("snmpNotifyFilterProfileTable")) shutdown_snmpNotifyFilterProfileTable();
  if (should_init("notification_log")) shutdown_notification_log();
  if (should_init("snmpTargetAddrEntry")) shutdown_snmpTargetAddrEntry();
  if (should_init("snmpTargetParamsEntry")) shutdown_snmpTargetParamsEntry();
  if (should_init("mteTriggerTable")) shutdown_mteTriggerTable();
  if (should_init("mteTriggerBooleanTable")) shutdown_mteTriggerBooleanTable();
  if (should_init("mteTriggerThresholdTable")) shutdown_mteTriggerThresholdTable();
  if (should_init("mteEventTable")) shutdown_mteEventTable();
  if (should_init("mteEventSetTable")) shutdown_mteEventSetTable();
  if (should_init("mteEventNotificationTable")) shutdown_mteEventNotificationTable();
  if (should_init("mteObjectsTable")) shutdown_mteObjectsTable();
  if (should_init("schedTable")) shutdown_schedTable();
  if (should_init("snmpNotifyTable_data")) shutdown_snmpNotifyTable_data();
  if (should_init("snmpNotifyFilterTable_data_storage")) shutdown_snmpNotifyFilterTable_data_storage();
  if (should_init("snmpNotifyFilterTable")) shutdown_snmpNotifyFilterTable();
  if (should_init("snmpNotifyFilterProfileTable_data")) shutdown_snmpNotifyFilterProfileTable_data();
  if (should_init("snmpTargetAddrEntry_data")) shutdown_snmpTargetAddrEntry_data();
  if (should_init("snmpTargetParamsEntry_data")) shutdown_snmpTargetParamsEntry_data();
  if (should_init("ifTable")) shutdown_ifTable();
  if (should_init("ifXTable")) shutdown_ifXTable();
  if (should_init("hw_fsys")) shutdown_hw_fsys();
  if (should_init("cpu")) shutdown_cpu();
